"use strict";

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

window.PrimetonCallback = {};
window.PrimetonCallback.registFunction = function (functionId, callback) {
	window.PrimetonCallback[functionId] = function (res) {
		if (isJsonString(res)) {
			res = JSON.parse(res);
		}
		callback(res);
	};
	return "window.PrimetonCallback." + functionId;
};

function isJsonString(str) {
	try {
		if (_typeof(JSON.parse(str)) == "object") {
			return true;
		}
	} catch (e) {}
	return false;
}

var primeton = {};

// 工具类接口
primeton.util = {};

// 安全请求 支持promise
primeton.promise = {};
/**
 * 获取当前设备唯一ID
 *
 * @param {function} Callback deviceId	string	获取当前设备Id
 */
primeton.getDeviceId = function (Callback) {
	var success = window.PrimetonCallback.registFunction("getDeviceId", Callback);
	var params = {
		success: success
	};
	window.android.getDeviceId(JSON.stringify(params));
};

/**
 * 隐藏右上角菜单接口
 */
primeton.hideOptionMenu = function () {
	window.android.hideOptionMenu();
};
/**
 * 显示右上角菜单接口
 */
primeton.showOptionMenu = function () {
	window.android.showOptionMenu();
};

/**
 * 关闭当前网页窗口接口
 */
primeton.closeWindow = function () {
	window.android.closeWindow();
};

/**
 *隐藏所有非基础按钮接口
 *
 */
primeton.hideAllNonBaseMenuItem = function () {
	window.android.hideAllNonBaseMenuItem();
};

/**
 *显示所有功能按钮接口
 *
 */
primeton.showAllNonBaseMenuItem = function () {
	window.android.showAllNonBaseMenuItem();
};

/**
 *批量隐藏功能按钮接口
 *
 * @param {Object} params menuList	string[]	是	要隐藏的菜单项，所有menu项见附录-菜单项列表
 */
primeton.hideMenuItems = function (params) {
	window.android.hideMenuItems(JSON.stringify(params));
};

/**
 *批量显示功能按钮接口
 *
 * @param {Object} params menuList	string[]	是	要显示的菜单项
 */
primeton.showMenuItems = function (params) {
	window.android.showMenuItems(JSON.stringify(params));
};

/**
 *设置页面标题栏颜色
 *
 * @param {string} color 顶部标题栏的颜色值
 */
primeton.setActionBarColor = function (color) {
	window.android.setActionBarColor(color);
};

primeton.onHistoryBack = function (call) {
	var success = window.PrimetonCallback.registFunction("onHistoryBack", call);
	var params = {
		success: success
	};
	window.android.onHistoryBack(JSON.stringify(params));
};

/**
 *设置本H5应用数据的接口，其他应用无法访问
 *
 * @param {Object} params json对象，数据包括 key	string	设置数据的key
 *						value	string	设置数据的value
 */
primeton.setValue = function (params) {
	window.android.setValue(JSON.stringify(params));
};

/**
 *根据key获取本H5应用储存的数据
 *
 * @param {Object} params
 */
primeton.getValue = function (params) {
	var success = window.PrimetonCallback.registFunction("getValue", params.success);
	var newParams = Object.assign(params, {
		success: success
	});
	window.android.getValue(JSON.stringify(newParams));
};

/**
 *设置App应用数据的接口，该数据各微应用之间共享
 *
 * @param {Object} params
 */
primeton.setGlobalValue = function (params) {
	window.android.setGlobalValue(JSON.stringify(params));
};

/**
 *根据key获取App储存的数据
 *
 * @param {Object} object
 */
primeton.getGlobalValue = function (params) {
	var success = window.PrimetonCallback.registFunction("getGlobalValue", params.success);
	var newParams = Object.assign(params, {
		success: success
	});
	window.android.getGlobalValue(JSON.stringify(newParams));
};

/**
 *获取地理位置接口
 *
 * @param {function} callback
 */
primeton.getLocation = function (callback) {
	var success = window.PrimetonCallback.registFunction("getLocation", callback);
	var params = {
		success: success
	};
	window.android.getLocation(JSON.stringify(params));
};

/**
 *打开持续定位接口
 *
 * @param {function} callback errCode	number	errCode为0则启动持续定位成功
 */
primeton.startAutoLBS = function (callback) {
	var success = window.PrimetonCallback.registFunction("startAutoLBS", callback);
	var params = {
		success: success
	};
	window.android.startAutoLBS(JSON.stringify(params));
};

/**
 *停止持续定位接口
 *
 * @param {function} callback
 */
primeton.stopAutoLBS = function (callback) {
	var success = window.PrimetonCallback.registFunction("stopAutoLBS", callback);
	var params = {
		success: success
	};
	window.android.stopAutoLBS(JSON.stringify(params));
};

/**
 *监听地理位置变化
 *
 * @param {function} callback
 */
primeton.onLocationChange = function (callback) {
	var success = window.PrimetonCallback.registFunction("onLocationChange", callback);
	var params = {
		success: success
	};
	window.android.onLocationChange(JSON.stringify(params));
};

/**
 *设置系统剪贴板的内容
 *
 * @param {Object} params 	data	string	设置剪贴板的内容
 *							success	function	成功回调
 *							fail	function	失败回调
 */
primeton.setClipboardData = function (params) {
	var success = window.PrimetonCallback.registFunction("setClipboardData", params.success);
	var newParams = Object.assign(params, {
		success: success
	});
	window.android.setClipboardData(JSON.stringify(newParams));
};

/**
 *调起App扫一扫接口
 *
 * @param {Object} params
 *  desc	string		否		扫一扫		扫一扫页面标题
 *	needResult	boolean	否		false		若为false则扫描结果是否由App端处理,不会再有success和error回调
 *	success	function	是		无			扫描成功回调，string类型
 *	error	function	是		无			扫描失败错误信息，string类型
 */
primeton.scanQRCode = function (params) {
	if (params.needResult) {
		var success = window.PrimetonCallback.registFunction("scanQRCode_success", params.success);
		var error = window.PrimetonCallback.registFunction("scanQRCode_error", params.error);
		var newParams = Object.assign(params, {
			success: success,
			error: error
		});
		window.android.scanQRCode(JSON.stringify(newParams));
	} else {
		window.android.scanQRCode(JSON.stringify(params));
	}
};

/**
 *获取本地图片接口
 *
 * @param {Object} params
 */
primeton.getLocalImgData = function (params) {
	var success = window.PrimetonCallback.registFunction("getLocalImgData", params.success);
	var newParams = Object.assign(params, {
		success: success
	});
	window.android.getLocalImgData(JSON.stringify(newParams));
};

/**
 *打开相机拍照
 *
 * @param {Object} params
 */
primeton.openCamera = function (params) {
	var success = window.PrimetonCallback.registFunction("openCamera", params.success);
	var newParams = Object.assign(params, {
		success: success
	});
	window.android.openCamera(JSON.stringify(newParams));
};

/**
 *从手机相册中选图接口
 *
 * @param {Object} params
 */
primeton.chooseImage = function (params) {
	var success = window.PrimetonCallback.registFunction("chooseImage", params.success);
	var newParams = Object.assign(params, {
		success: success
	});
	window.android.chooseImage(JSON.stringify(newParams));
};

/**
 *预览图片接口
 *
 * @param {Object} params
 */
primeton.previewImage = function (params) {
	window.android.previewImage(JSON.stringify(params));
};

/**
 *下载图片接口
 *
 * @param {Object} params
 */
primeton.downloadImage = function (params) {
	var success = window.PrimetonCallback.registFunction("downloadImage", params.success);
	var newParams = Object.assign(params, {
		success: success
	});
	window.android.downloadImage(JSON.stringify(newParams));
};

/**
 * 获取全局变量的值
 * @param {string} key 储存的key值
 * @param {bool} shouldDelete 是否删除
 * @param {string} callbackId 回调方法名
 */

/**
 *获取功能菜单中"微信"按钮点击状态及自定义分享内容接口
 *
 * @param {Object} params
 */
primeton.onMenuShareWechat = function (params) {
	var success = window.PrimetonCallback.registFunction("onMenuShareWechat_success", params.success);
	var cancel = window.PrimetonCallback.registFunction("onMenuShareWechat_cancel", params.cancel);
	var fail = window.PrimetonCallback.registFunction("onMenuShareWechat_fail", params.fail);
	var newParams = Object.assign(params, {
		success: success,
		fail: fail,
		cancel: cancel
	});
	window.android.onMenuShareWechat(JSON.stringify(newParams));
};

/**
 *获取功能菜单中"分享到朋友圈"按钮点击状态及自定义分享内容接口
 *
 * @param {Object} params
 */
primeton.onMenuShareTimeline = function (params) {
	var success = window.PrimetonCallback.registFunction("onMenuShareTimeline_success", params.success);
	var cancel = window.PrimetonCallback.registFunction("onMenuShareTimeline_cancel", params.cancel);
	var fail = window.PrimetonCallback.registFunction("onMenuShareTimeline_fail", params.fail);
	var newParams = Object.assign(params, {
		success: success,
		fail: fail,
		cancel: cancel
	});
	window.android.onMenuShareTimeline(JSON.stringify(newParams));
};
/**
 *分享到微信
 *
 * @param {Object} params
 */
primeton.shareToWechat = function (params) {
	var success = window.PrimetonCallback.registFunction("shareToWechat_success", params.success);
	var cancel = window.PrimetonCallback.registFunction("shareToWechat_cancel", params.cancel);
	var fail = window.PrimetonCallback.registFunction("shareToWechat_fail", params.fail);
	var newParams = Object.assign(params, {
		success: success,
		fail: fail,
		cancel: cancel
	});
	window.android.shareToWechat(JSON.stringify(newParams));
};

/**
 *分享到微信朋友圈
 *
 * @param {Object} params
 */
primeton.shareToTimeline = function (params) {
	var success = window.PrimetonCallback.registFunction("shareToTimeline_success", params.success);
	var cancel = window.PrimetonCallback.registFunction("shareToTimeline_cancel", params.cancel);
	var fail = window.PrimetonCallback.registFunction("shareToTimeline_fail", params.fail);
	var newParams = Object.assign(params, {
		success: success,
		fail: fail,
		cancel: cancel
	});
	window.android.shareToTimeLine(JSON.stringify(newParams));
};

primeton.util.saveContactEvent = function (params) {
	var success = window.PrimetonCallback.registFunction("saveContactEvent_success", params.success);
	var fail = window.PrimetonCallback.registFunction("saveContactEvent_failed", params.fail);
	var newParams = Object.assign(params, {
		success: success,
		fail: fail
	});
	window.android.saveContactEvent(JSON.stringify(newParams));
};

primeton.util.removeContactEvent = function (params) {
	var success = window.PrimetonCallback.registFunction("removeContactEvent_success", params.success);
	var fail = window.PrimetonCallback.registFunction("removeContactEvent_failed", params.fail);
	var newParams = Object.assign(params, {
		success: success,
		fail: fail
	});
	window.android.removeContactEvent(JSON.stringify(newParams));
};

/**
 *是否开启安全通道（H5）
 *
 * @param {function} callback
 */
primeton.securityChannelEnable = function (ChannelCallback) {
	var callback = window.PrimetonCallback.registFunction("securityChannelEnable_callback", ChannelCallback);
	var params = {
		callback: callback
	};
	window.android.securityChannelEnable(JSON.stringify(params));
};

/**
 *支持网关验证和安全通道的网络请求接口（H5）
 *
 * @param {Object} params
 */
primeton.securityRequest = function (params) {
	var success = window.PrimetonCallback.registFunction("securityRequest_success", params.success);
	var fail = window.PrimetonCallback.registFunction("securityRequest_fail", params.fail);
	var newParams = Object.assign(params, {
		success: success,
		fail: fail
	});
	window.android.securityRequest(JSON.stringify(newParams));
};

/**
 *安全通道开启时加密方法（H5）
 *
 * @param {Object} params
 */
primeton.securityRequestEncrypt = function (params) {
	var success = window.PrimetonCallback.registFunction("securityRequestEncrypt_success", params.success);
	var fail = window.PrimetonCallback.registFunction("securityRequestEncrypt_fail", params.fail);
	var newParams = Object.assign(params, {
		success: success,
		fail: fail
	});
	window.android.securityRequestEncrypt(JSON.stringify(newParams));
};

/**
  *安全通道开启时解密方法（H5）
  *
  * @param {Object} params
  */
primeton.securityRequestDecrypt = function (params) {
	var success = window.PrimetonCallback.registFunction("securityRequestDecrypt_success", params.success);
	var fail = window.PrimetonCallback.registFunction("securityRequestDecrypt_fail", params.fail);
	var newParams = Object.assign(params, {
		success: success,
		fail: fail
	});
	window.android.securityRequestDecrypt(JSON.stringify(newParams));
};

/**
 *获取网关验证需要的请求头（H5）
 *
 * @param {function} gatewayCallback
 */
primeton.getGatewayHeaders = function (gatewayCallback) {
	var callback = window.PrimetonCallback.registFunction("getGatewayHeaders_callback", gatewayCallback);
	var params = {
		callback: callback
	};
	window.android.getGatewayHeaders(JSON.stringify(params));
};

/**
 *安全通道开启时加密方法(Promise)
 *
 * @param {String} content
 * @returns
 */
primeton.promise.securityRequestEncrypt = function (content) {
	return new Promise(function (resolve, reject) {
		var params = {
			content: content,
			success: function success(res) {
				resolve(res);
			},
			fail: function fail(err) {
				reject(err);
			}
		};
		window.primeton.securityRequestEncrypt(params);
	});
};

/**
 *安全通道开启时解密方法(Promise)
 *
 * @param {String} content
 * @returns
 */
primeton.promise.securityRequestDecrypt = function (content) {
	return new Promise(function (resolve, reject) {
		var params = {
			content: content,
			success: function success(res) {
				resolve(res);
			},
			fail: function fail(err) {
				reject(err);
			}
		};
		window.primeton.securityRequestDecrypt(params);
	});
};

/**
 *获取网关验证需要的请求头(Promise)
 *
 * @returns 返回Promise对象
 */
primeton.promise.getGatewayHeaders = function () {
	return new Promise(function (resolve, reject) {
		window.primeton.getGatewayHeaders(function (res) {
			resolve(res);
		});
	});
};

/**
 *是否开启安全通道(Promise)
 *
 * @param {function} ChannelCallback
 * @returns 返回Promise对象
 */
primeton.promise.securityChannelEnable = function (ChannelCallback) {
	return new Promise(function (resolve, reject) {
		window.primeton.securityChannelEnable(function (res) {
			resolve(res);
		});
	});
};

/**
 *支持网关验证和安全通道的网络请求接口(Promise)
 *
 * @param {Object} params
 * @returns 返回Promise对象
 */
primeton.promise.securityRequest = function (params) {
	return new Promise(function (resolve, reject) {
		var newParams = Object.assign(params, {
			success: function success(res) {
				resolve(res);
			},
			fail: function fail(err) {
				reject(err);
			}
		});
		window.primeton.securityRequest(newParams);
	});
};

/**
 *接收RN发送过来的事件，开发者需要调用此方法监听事件
 *
 * @param {function} eventCallback
 */
primeton.onEventListener = function (eventCallback) {
	var callback = window.PrimetonCallback.registFunction("onEventListener_callback", eventCallback);
	window.android.onEventListener(callback);
};

/**
 *获取用户信息
 *
 * @param {function} userInfoCallback
 */
primeton.getUserInfo = function (userInfoCallback) {
	var callback = window.PrimetonCallback.registFunction("getUserInfo_callback", userInfoCallback);
	var params = {
		callback: callback
	};
	window.android.getUserInfo(JSON.stringify(params));
};
/**
 *文件上传
 *
 * @param {function} uploadFile
 */
primeton.uploadFile = function(params){
    let success = window.PrimetonCallback.registFunction("uploadFile_success",params.success)
    let fail = window.PrimetonCallback.registFunction("uploadFile_fail",params.fail)
    var newParams = Object.assign(params, {
            		success: success,
            		fail:fail
            	});
    window.android.uploadFile(JSON.stringify(params));
}

/**
 *视频录制
 *
 * @param {function} videoRecord
 */
primeton.videoRecord = function(params){
    let success = window.PrimetonCallback.registFunction("videoRecord_success",params.success)
    let fail = window.PrimetonCallback.registFunction("videoRecord_fail",params.fail)
    var newParams = Object.assign(params, {
        		success: success,
        		fail:fail
        	});
    window.android.videoRecord(JSON.stringify(newParams));

}

window.primeton = primeton;
/**
 *向RN发送事件
 *
 * @param {Object} object
 */
primeton.sendRnEvent = function (object) {
	window.android.sendRnEvent(JSON.stringify(object));
};

window.primeton = primeton;